function [u_E, u_A, u_P] = ACX_CommandSwashplate( swash_cmd, ...
                                                  swash_cfg, ...
                                                  servo_cfgs )
%##########################################################################
% [] = ACX_CommandSwashplate( swash_cmd )
%
% Send command to swashplate
% 
% swash_cmd  :  Swashplate pose swash_cmd = [phi_1c, phi_1s, h_sp];
% swash_cfg  :  Parameters defining the swashplate inverse kinematics
% servo_cfgs :  
%--------------------------------------------------------------------------
% Author: Christoph Huerzeler (ASL-ETHZ)
% Date: 2011
% Email: christoph.huerzeler@mavt.ethz.ch
%##########################################################################
%#codegen

%% Calculate the servo commands from desired swashplate pose
phi_1c = -swash_cmd(1);
phi_1s = -swash_cmd(2);
h_sp   = swash_cmd(3);

%% Calculate the desired servo angles
kE    = swash_cfg.ELEVATOR_COEFFS;
kA    = swash_cfg.AILERON_COEFFS;
kP    = swash_cfg.PITCH_COEFFS;
phi_E = kE(1)*phi_1c + kE(3)*h_sp   + kE(4)/h_sp;
phi_A = kA(1)*phi_1c + kA(2)*phi_1s + kA(3)*h_sp + kA(4)/h_sp;
phi_P = kP(1)*phi_1c + kP(2)*phi_1s + kP(3)*h_sp + kP(4)/h_sp;


%% Calculate the desired servo signals
% Elevator
STATIC_COEFFS = servo_cfgs.ELEVATOR_SERVO.STATIC_COEFFS;
k1            = STATIC_COEFFS(1);
k2            = STATIC_COEFFS(2);
k3            = STATIC_COEFFS(3);
u_E           = k1*phi_E^2 + k2*phi_E + k3;

% Aileron
STATIC_COEFFS = servo_cfgs.AILERON_SERVO.STATIC_COEFFS;
k1            = STATIC_COEFFS(1);
k2            = STATIC_COEFFS(2);
k3            = STATIC_COEFFS(3);
u_A           = k1*phi_A^2 + k2*phi_A + k3;

% Pitch
STATIC_COEFFS = servo_cfgs.PITCH_SERVO.STATIC_COEFFS;
k1            = STATIC_COEFFS(1);
k2            = STATIC_COEFFS(2);
k3            = STATIC_COEFFS(3);
u_P           = k1*phi_P^2 + k2*phi_P + k3;


%% -- end of file
