function [NomChecks,FAChecks] = ACX_SIM_Check_SISO_IO_FIXCOHTHRES(output_vec,input_vec,Ts,options)
%
%   Syntax:
%   [NomChecks,FAChecks] = ACX_SIM_Check_SISO_IO(output_vec,input_vec,Ts,options)
%
%   Inputs:
%   output_vec      : output vector
%   input_vec       : input vector
%   Ts              : sampling time
%   options         : structure that contains the coherence options
%   options.Window   = Windowing function and number of samples to
%                              use for each section
%           options.Noverlap = Number of samples by which the sections 
%                              overlap
%           options.NFFT     = FT length which determines the frequencies 
%                              at which the coherence is estimated
%           options.plot     = if == 1 then the coherence is being plot
%           options.f1       = lower frequency bound
%           options.f2       = highest frequency bound
%           
%   Outputs:
%   NomChekcs       : Coherence, Random Error computations for all
%   frequency area
%   FAChekcs        : Coherence, Random Error computations for specified
%   frequency area
%   
%   Plots and provides the values (and mean values) for the coherence and
%   random error computed over the whole frequency area and the predefined
%   frequency area.
%
%   Authors:    Kostas Alexis (konstantinos.alexis@mavt.ethz.ch)
%

if(isfield(options,'Noverlap'))
    options.noverlap = options.Noverlap;
end
if(isfield(options,'noverlap'))
    options.Noverlap = options.noverlap;
end

if(isfield(options,'NFFT'))
    options.nfft = options.NFFT;
end

if(isfield(options,'nfft'))
    options.NFFT = options.nfft;
end

Fs = 1/Ts;

FreqLH = [options.f1 options.f2];
CoherenceThreshold = 0.6;

cprintf('SystemCommands','Coherence plot between Input and Output\n');
[NomChecks.Coherence,FAChecks.Coherence] = SIM_FAcohere(input_vec,output_vec,options,Fs,FreqLH(1),FreqLH(2));

[RandomFrqError,Freqs] = rand_freq_error(input_vec,output_vec,options);

cre = 1;
for kk = 1:length(Freqs)
    if((Freqs(kk)>=options.f1)&&(Freqs(kk)<=options.f2))
    re_freq_area(cre) = RandomFrqError(kk);
    freq_area(cre)=Freqs(kk);
    cre = cre+1;
    end
end
RandomErrorsAtFreqAreas = sum(re_freq_area)/length(re_freq_area);

NomChecks.RandomError.values = RandomFrqError;
NomChecks.RandomError.freqs = Freqs;
NomChecks.RandomError.meanValue = sum(RandomFrqError)/length(RandomFrqError);

FAChecks.RandomError.values = re_freq_area;
FAChecks.RandomError.freqs = freq_area;
FAChecks.RandomError.meanValue = RandomErrorsAtFreqAreas;

if(NomChecks.Coherence.meanValue>=CoherenceThreshold)
    cprintf('Blue','Nominal Coherence exceeds the required threshold!\n');
else
    cprintf('Red','Nominal Coherence is below the required threshold\n');
end

if(FAChecks.Coherence.meanValue>=CoherenceThreshold)
    cprintf('Blue','The Coherence at the specified frequency area exceeds the required threshold!\n');
else
    cprintf('Red','The Coherence at the specified frequency area is below the required threshold\n');
end

if(options.plot == 1)
cl_flg = input('Press ~=0 to close all figures');
if(cl_flg ~=0)
    close all
end
end

end
