function SIM_Datasets = ACX_SIM_Create_Dataset(ATTI_SIM,YAWR,HEAVEZW,XY_VEL_RM,X_WPTS,Y_WPTS,CONACT,SWPL_OMEGA,ctrl_pos_select,Ts)
%
%   Syntax:
%   SIM_Datasets = ACX_SIM_Create_Dataset(ATTI_SIM,YAWR,HEAVEZW,XY_VEL_RM,X_WPTS,Y_WPTS,ctrl_pos_select,Ts)
%
%   This function creates the Structure SIM_Datasets which contains all the
%   reference and response signals of one specific ACX Linear Simulator
%   execution.
%
%   Authors: Kostas Alexis (konstantinos.alexis@mavt.ethz.ch)
%

SIM_Datasets.Attitude.phi_ref = ATTI_SIM.signals(1).values(:,1);
SIM_Datasets.Attitude.phi_resp = ATTI_SIM.signals(1).values(:,2);
SIM_Datasets.Attitude.p_ref = ATTI_SIM.signals(2).values(:,1);
SIM_Datasets.Attitude.p_resp = ATTI_SIM.signals(2).values(:,2);
SIM_Datasets.Attitude.theta_ref = ATTI_SIM.signals(3).values(:,1);
SIM_Datasets.Attitude.theta_resp = ATTI_SIM.signals(3).values(:,2);
SIM_Datasets.Attitude.q_ref = ATTI_SIM.signals(4).values(:,1);
SIM_Datasets.Attitude.q_resp = ATTI_SIM.signals(4).values(:,2);
SIM_Datasets.YawHeave.psi_ref = YAWR.signals(1).values(:,1);
SIM_Datasets.YawHeave.psi_resp = YAWR.signals(1).values(:,2);
SIM_Datasets.YawHeave.r_ref = YAWR.signals(2).values(:,1);
SIM_Datasets.YawHeave.r_resp = YAWR.signals(2).values(:,2);
SIM_Datasets.YawHeave.z_ref = HEAVEZW.signals(1).values(:,1);
SIM_Datasets.YawHeave.z_resp = HEAVEZW.signals(1).values(:,2);
SIM_Datasets.YawHeave.w_ref = HEAVEZW.signals(2).values(:,1);
SIM_Datasets.YawHeave.w_resp = HEAVEZW.signals(2).values(:,2);
SIM_Datasets.Position.x_resp = XY_VEL_RM.signals(1).values(:,2);
SIM_Datasets.Position.u_resp = XY_VEL_RM.signals(3).values(:,2);
SIM_Datasets.Position.y_resp = XY_VEL_RM.signals(2).values(:,2);
SIM_Datasets.Position.v_resp = XY_VEL_RM.signals(4).values(:,2);
if(ctrl_pos_select(end) == 1)
    SIM_Datasets.Position.x_ref = XY_VEL_RM.signals(1).values(:,1);
    SIM_Datasets.Position.u_ref = XY_VEL_RM.signals(3).values(:,1);
    SIM_Datasets.Position.y_ref = XY_VEL_RM.signals(2).values(:,1);
    SIM_Datasets.Position.v_ref = XY_VEL_RM.signals(4).values(:,1);
else
    xx = XY_VEL_RM.signals(1).values(:,2);
    yy = XY_VEL_RM.signals(2).values(:,2);
    xx_ref = X_WPTS;
    yy_ref = X_WPTS;
    [x_wpts_ref,y_wpts_ref] = InterpXY_WPTS(X_WPTS,Y_WPTS,xx);
    dot_x = diff(x_wpts_ref)/Ts;
    dot_x(end+1) = 0;
    dot_y = diff(y_wpts_ref)/Ts;
    dot_y(end+1) = 0;
    SIM_Datasets.Position.x_ref = x_wpts_ref;
    SIM_Datasets.Position.u_ref = dot_x;
    SIM_Datasets.Position.y_ref = y_wpts_ref;
    SIM_Datasets.Position.v_ref = dot_y;
end
SIM_Datasets.ControlActions.Normalized.u_roll = CONACT.signals(1).values(:,1);
SIM_Datasets.ControlActions.Normalized.u_pitch = CONACT.signals(2).values(:,1);
SIM_Datasets.ControlActions.Normalized.u_yaw = CONACT.signals(3).values(:,1);
SIM_Datasets.ControlActions.Normalized.u_thrust = CONACT.signals(4).values(:,1); 
SIM_Datasets.ControlActions.SWPL_Motor.phi_1c = SWPL_OMEGA.signals(1).values;
SIM_Datasets.ControlActions.SWPL_Motor.phi_1s = SWPL_OMEGA.signals(2).values;
SIM_Datasets.ControlActions.SWPL_Motor.h_sp = SWPL_OMEGA.signals(3).values;
SIM_Datasets.ControlActions.SWPL_Motor.Omega = SWPL_OMEGA.signals(4).values;
SIM_Datasets.Ts = Ts;
end 