function FRD_Analysis = ACX_SIM_SISO_FRD_Analysis(u,y,Ts,options)
%
%   SISO Experimental Frequency Domain Analysis
%
%   Syntax:
%   FRD_Analysis = ACX_SIM_SISO_FRD_Analysis(u,y,Ts)
%   
%   ACX ConTRoL Design Interfrace
%
%   Outputs:
%   FRD_Analysis     : Results Structure
%   FRD_Analysis.Bandwidth  : FFT based estimated bandwidth
%   FRD_Analysis.FRDobj     : Frequency Domain Object
%   FRD_Analysis.ETFEobj    : ETFE-estimated Transfer Function Object
%
%   Inputs:
%   u                : experimental input
%   y                : experimental output
%   Ts               : sampling period
%   options          : options structure containing:
%   options.Bandwdith : Bandwidth threshold
%
%   Authors: Kostas Alexis (konstantinos.alexis@mavt.ethz.ch)
%

cprintf('SystemCommands','Note that this is rough Frequency Domain Estimation...\n');

NFFT = 2^nextpow2(length(y)); % Next power of 2 from length of y
Fs = 1/Ts;
Y = fft(y,NFFT)/length(y);
U = fft(u,NFFT)/length(u);
%GG = Y./U;
GG = tfestimate(u,y,rectwin(floor(NFFT/2)),floor(NFFT/20),NFFT,Fs);

%GG = tfestimate(u,y,options.Window,options.Noverlap,options.NFFT,Fs,'onesided');
w = Hz2rad_s((Fs/2)*linspace(0,1,length(GG)));
frd_obj = frd(GG,w,Ts);
e_bandwidth = bandwidth(frd_obj);

if(e_bandwidth>= options.Bandwidth)
    cprintf('Blue','Estimated Bandwidth is above the required threshold!\n');
else
    cprintf('Red','Estimated Bandwidth is lower than the required threshold\n');
end

FRD_Analysis.Bandwidth = e_bandwidth;
FRD_Analysis.FRDobj = frd_obj;
FRD_Analysis.DCgain = dcgain(frd_obj);

data = iddata(y,u,Ts);

FRD_Analysis.ETFEobj = etfe(data);

%figure;
bode(frd_obj);
grid on;

cprintf('Black',         '----------------------------------------------------------------------\n');
cprintf('SystemCommands','Be extremely careful on how you interpret and how much you trust\n');
cprintf('SystemCommands','these estimations. They greatly change according to a number of\n');
cprintf('SystemCommands','parameters like the utilized filters, the type of responses and so on.\n');
cprintf('Black',         '----------------------------------------------------------------------\n');
end