function [PSDuu,PSDyy,PSDuy] = SIM_PSD_IO(u,y,options)
%   
%   Power Spectral Density Estimate: auto PSD input, output and cross PSD
%   
%   Syntax:
%   [PSDuu,PSDyy,PSDuy] = SIM_PSD_IO(u,y,options)
%   
%   ### AIROBOTS COAX Small System Identification Toolbox
%
%   Inputs:
%   u           : Input vector
%   y           : Output vector
%   options     : structure that contains the options on how to do the
%   spectrogram and how to export data. Specifically: 
%           options.Fs      : sampling frequency
%           options.Window  : Windowing function
%           options.noverlap: no overlap value
%           options.nfft    : nfft value
%           options.plot    : if == 1 plots the Random-Error function
%
%   Outputs:
%   PSDuu       : Input auto PSD
%   PSDyy       : Output auto PSD
%   PSDuy       : Input/Output cross PSD
%
%   Authors:    Kostas Alexis (konstantinos.alexis@mavt.ethz.ch)
%

pars_flag = input('Do you want default NFFT,Noverlap,Window options or yours [0 = default/1 = yours]?');

if(pars_flag == 1) 
    Puu = abs(fft(u,options.NFFT)).^2/length(u)/options.Fs;
else
    nfft = 2^nextpow2(length(u));
    Puu = abs(fft(u,nfft)).^2/length(u)/options.Fs;
end
PSDuu = dspdata.psd(Puu(1:length(Puu)/2),'Fs',options.Fs);
if(pars_flag == 1)
    Pyy = abs(fft(y,options.NFFT)).^2/length(y)/options.Fs;
else
    nfft = 2^nextpow2(length(y)); % actually the same as above..
    Pyy = abs(fft(y,nfft)).^2/length(y)/options.Fs;
end
PSDyy = dspdata.psd(Pyy(1:length(Pyy)/2),'Fs',options.Fs);

if(pars_flag==1)
    [PSDc,wuy] = cpsd(u,y,options.Window,options.Noverlap,options.NFFT,options.Fs);
else
    [PSDc,wuy] = cpsd(u,y,[],[],[],options.Fs);
end
PSDuy.Data = PSDc;
PSDuy.Frequencies = wuy;

if(options.plot==1)
    subplot(2,2,[1 2])
    if(pars_flag==1)
        cpsd(u,y,options.Window,options.Noverlap,options.NFFT,options.Fs);
    else
        cpsd(u,y,[],[],[],options.Fs);
    end
    title('Input-Output Cross Power Spectral Density Estimate');
    subplot(2,2,3)
    plot(PSDuu);
    grid on
    subplot(2,2,4)
    plot(PSDyy);
end
