function [Spectro] = SIM_SpectrogramIO(u,y,options)
%   
%   Spectrogram between Input and Output
%   
%   Syntax:
%   [Spectro] = SIM_SpectrogramIO(u,y,options)
%
%   Inputs:
%   u           : Input vector
%   y           : Output vector
%   options     : structure that contains the options on how to do the
%   spectrogram and how to export data. Specifically: 
%           options.Fs      : sampling frequency
%           options.Window  : Windowing function
%           options.noverlap: no overlap value
%           options.nfft    : nfft value
%           options.plot    : if == 1 plots the Random-Error function
%
%   Outputs:
%   Spectro.Input.S, Spectro.Output.S : is the Short-Time Fourier Transform
%   of the input and the output signal respectively
%   Spectro.Input.F, Spectro.Output.F : are the frequencies corresponding 
%   to the values of the S array for input and output
%   Spectro.Input.T, Spectro.Output.T : are  the time instances over which
%   the spectrogram is computed
%
%   Authors:    Kostas Alexis (konstantinos.alexis@mavt.ethz.ch)
%

if(isfield(options,'Noverlap'))
    options.noverlap = options.Noverlap;
end

if(isfield(options,'NFFT'))
    options.nfft = options.NFFT;
end

if(isfield(options,'noverlap'))
    options.Noverlap = options.noverlap;
end

if(isfield(options,'nfft'))
    options.NFFT = options.nfft;
end

[Spectro.Input.S, Spectro.Input.F, Spectro.Input.T, Spectro.Input.P] = spectrogram(u,options.Window,options.noverlap,options.nfft,options.Fs);
[Spectro.Output.S, Spectro.Output.F, Spectro.Output.T, Spectro.Output.P] = spectrogram(y,options.Window,options.noverlap,options.nfft,options.Fs);

if(options.plot == 1);
 %   figure;
    subplot(2,1,1);
    spectrogram(u,options.Window,options.noverlap,options.nfft,options.Fs);
    title('Spectrogram of Input');
    xlim([0 20]);
    subplot(2,1,2);
    spectrogram(y,options.Window,options.noverlap,options.nfft,options.Fs);
    title('Spectrogram of Output');
    xlim([0 20]);
end

cprintf('Blue','Spectrograms computed\n');

end