%%  AIROBOTS Coaxial Helicopter Prototype Linear Simulator (ACX_Simulator_L)
%
%   Authors: Kostas Alexis (konstantinos.alexis@mavt.ethz.ch)
%
%
%   The AIROBOTS Coaxial Helicopter Prototype Linear Simulator
%   (ACX_Simulator_L) is a MATLAB-Simulink Block that contains:
%   - Blocks Identified Grey-Box State-Space Models for the Roll/Pitch
%   (with flapping dynamics), yaw, heave and linear velocities/position
%   dynamics
%   - The baseline Free-Flight Controllers that are used for the
%   experimental platform (in a simplified form without all the implemented
%   functionality) 
%   - Model-Based controllers for these dynamics
%   - Empty blocks to implement your own controller
%   The ACX_Simulator_L is accompanied with MATLAB functions for post
%   analysis. 
%
%
%   -----------------------------------------------------------------------
%   1. The Roll/Pitch Dynamics Identified State-Space Model
%   -----------------------------------------------------------------------
%
%   States: 
%   \phi, p, \theta, q, \alpha, \beta, \gamma, \delta, \epsilon, \zeta
%
%   Inputs:
%   u_roll, u_pitch translated to \phi_{1c}, \phi_{1s}
%
%   Where:
%   \alpha      -> longitudinal flapping Lower Rotor
%   \beta       -> lateral flapping Lower Rotor
%   \gamma      -> longitudinal flapping Upper Rotor
%   \delta      -> lateral flapping Upper Rotor
%   \epsilon    -> longitudinal flapping Flybar
%   \zeta       -> lateral flapping Flybar
%
%   \phi_{1c}   -> longitudinal tilting of the Swashplate
%   \phi_{1s}   -> lateral tilting of the Swashplate
%
%   
%   -----------------------------------------------------------------------
%   2. The Yaw Dynamics Identified State-Space Model
%   -----------------------------------------------------------------------
% 
%   States
%   \psi, r
%
%   Inputs:
%   u_yaw, u_thrust translated to h_{sp} and \Omega
%   
%   Where:
%   h_{sp}      -> Swashplate height
%   \Omega      -> The lower rotor speed
%
%   -----------------------------------------------------------------------
%   3. The Heave Dynamics Identified State-Space Model
%   -----------------------------------------------------------------------
%
%   States
%   z, w
%
%   Inputs:
%   u_yaw, u_thrust translated to h_{sp} and \Omega
%
%   Where:
%   h_{sp}      -> Swashplate height
%   \Omega      -> The lower rotor speed
%   -----------------------------------------------------------------------
%   4. The Position/velocity Dynamics
%   -----------------------------------------------------------------------
%
%   States
%   x,u,y,v
%
%   Inputs:
%   \phi, \theta
%
%   -----------------------------------------------------------------------
%   5. The Experimental Controllers
%   -----------------------------------------------------------------------
% 
%   For all degrees of freedom Gain Scheduled cascaded PID loops are
%   utilized combined with off-axis response compensation blocks. For the
%   simulator only the dominant functionality is implemented since some of
%   the undesirable effects are not captured.
%
%   -----------------------------------------------------------------------
%   6. Post Analysis Functionality
%   -----------------------------------------------------------------------
%
%   Time Domain:
%   Plots Reference - Response
%   Mean Square Errors
%   Fitting Percentages
%
%   Frequency Domain:
%   FFT Reference - Response
%   Nonparameteric Frequency Response Estimation
%
%   -----------------------------------------------------------------------
%   7. Parametric Identification
%   -----------------------------------------------------------------------
%
%   Some Identification funcionality based on MATLAB's System
%   Identification toolbox is provided. Additional functionality is also
%   provided for proper data preparation, model validation and utilization
%   of the chirp-z transform for the identification process. The
%   implemented functionality supports identification schemes for:
%   a) Transfer Function identification
%   b) Single Input - Single Output State Space Identification
%   c) Multi Input - Single Output State Space Identification
%
%   
%   -----------------------------------------------------------------------
%   8. Nonparametric Identification
%   -----------------------------------------------------------------------
%
%   Nonparametric identification is a direct way to make conclusions about
%   the system characteristics without a specific parametric model. If
%   properly used it can aid the systems and control engineer to identify
%   critical response characteristics (like a resonance pole frequency).
%   The ACX Simulator provides some limited functionality such as frequency
%   response estimation, coherence checks, step response analysis etc.
%
%   -----------------------------------------------------------------------
%   For further information: 
%   Look at the PDF documents inside the directory /Help_Files
%
%   For questions or notes send an e-mail at:
%   konstantinos.alexis@mavt.ethz.ch
%   -----------------------------------------------------------------------
%   -----------------------------------------------------------------------

