function IOCheck = ACX_SIM_SISO_ResponseCheck(r,y,options)
%
%   Syntax: 
%   IOCheck = ACX_SIM_SISO_ResponseCheck(r,y,options)
%
%   Inputs:
%   r   : signal 1
%   y   : signal 2
%   options : options object
%
%   Outputs:
%   IOCheck : Contains Fitting, Coherence and Random Error results
%
%   This function plots a figure with all critical information about the
%   relation of signal r with y
%   
%   Authors: Kostas Alexis (konstantinos.alexis@mavt.ethz.ch)
%
time_vec = options.Ts*(1:length(r))-options.Ts;

fit = 100*(1 - norm(y - r)/norm(r-mean(r))); % ['ID - Fit = ' num2str(fit) '%']
oldPlotOption = options.plot;
options.plot = 0;
[NomChecks,FAChecks] = ACX_SIM_Check_SISO_IO_FIXCOHTHRES(r,y,options.Ts,options);
options.plot = oldPlotOption;

IOCheck.Fit = fit;
IOCheck.NomCoherence = NomChecks;
IOCheck.FACoherence = FAChecks;

subplot(2,2,[1 2])
plot(time_vec,r);
hold on
plot(time_vec,y,'r')
xlabel('Time (s)'); ylabel('Signal');
hlegs = legend('Exp',['ID - Fit = ' num2str(fit) '%']);
grid on
subplot(2,2,3)
plot(NomChecks.Coherence.freqs,NomChecks.Coherence.coherence,'b');
hold on
plot(FAChecks.Coherence.freqs,FAChecks.Coherence.coherence,'g');
grid on
xlabel('Frequency (Hz)'); ylabel('Coherence Magnitude');
hlegc = legend(['Nominal ' num2str(NomChecks.Coherence.meanValue)],['Spec Freqs ' num2str(FAChecks.Coherence.meanValue)]);
subplot(2,2,4)
plot(NomChecks.RandomError.freqs,NomChecks.RandomError.values,'b');
hold on
plot(FAChecks.RandomError.freqs,FAChecks.RandomError.values,'g');
grid on
xlabel('Frequency (Hz)'); ylabel('Random Error');
hlegre = legend(['Nominal ' num2str(NomChecks.RandomError.meanValue)],['Spec Freqs ' num2str(FAChecks.RandomError.meanValue)]);

end