function DAMP_Analysis = ACX_SIM_SISO_STEP_DampingAnalysis(u,y,options)
%
%   SISO STEP Response Based Approximate Damping Analysis
%
%   Syntax:
%   DAMP_Analysis = ACX_SIM_SISO_STEP_DampingAnalysis(u,y,options)
%   
%   ### ACX ConTRoL Design Interfrace
%
%   Outputs:
%   DAMP_Analysis               : Results structure      
%   DAMP_Analysis.DampingRatio  : approximate dominant damping ratio
%   DAMP_Analysis.Wmega_n       : approximate dominant natural frequency
%   DAMP_Analysis.Wmega_d       : approximate bandwidth
%
%   Inputs:
%   u           : Input Vector
%   y           : Output Vector
%   options     : options structure
%   options.Zeta    Threshold for the damping ratio
%   options.Overshoot    : maximum acceptable overshoot
%   options.SettlingTimeCr : settling time Criterion % (e.g. 2%)
%
%   Authors: Kostas Alexis (konstantinos.alexis@mavt.ethz.ch)
%

Ts  = options.Ts;
t = Ts*(1:length(y))  - Ts;

SISO_STEP_TEST = ACX_SIM_SISO_Exp_Step_Test(u,y,t,options);

OV_e = SISO_STEP_TEST.OvershootValue;

zeta_d = abs(log(OV_e/100))/sqrt(pi^2 + (log(OV_e/100))^2);

set_time = SISO_STEP_TEST.SettlingTime;

Wmega_n = -log(2*options.SettlingTimeCr/100)/(zeta_d*set_time); % why *2? because we define settling criterion as +- criterion but the algorithm they use for this computation assumes criterion as total max-min
cprintf('SystemCommands','NOTE!!!! Wmega_n estimation typically fails...\n');
DAMP_Analysis.DampingRatio = zeta_d;
DAMP_Analysis.Wmega_n = Wmega_n;
DAMP_Analysis.Wmega_d = Wmega_n*sqrt(1-(zeta_d^2)); 
cprintf('SystemCommands','NOTE!!! Wmega_d is also not accurate due to the Wmega_n problems...\n');
cprintf('Green','It is recommended that for natural frequencies you should look at DAMP_Analysis.Wn\n');
cprintf('Green','Even see all the damping ratios from DAMP_Analysis.All_Zetas\n');

isnancheck = isnan(zeta_d);
if(isnancheck~=1)
if(zeta_d>=options.Zeta)
    cprintf('Blue','The system has good damping! (based on dominant damping ratio approximation)\n');
else
    cprintf('Red','The system has small damping ratio (based on dominal damping ratio approximation)\n');
end
else
    cprintf('SystemCommands','Approximation of damping ratio resulted NaN -> check DAMP_Analysis.All_Zetas\n')
end

end